@@ -19,7 +19,7 @@ DATA <- DATA %>% mutate(
 # whereas factor(DATA$A3) will order the levels
 # by c("TREAT0", "TREAT1", "TREAT2").
 
-test_that("GLM full function -- linear (ANOVA)", {
+test_that("Test ordering of treatment factors in GLM adjustment", {
 
   # The locale is actually the issue -- testthat
   # automatically sets locale C but the issue only
@@ -29,7 +29,7 @@ test_that("GLM full function -- linear (ANOVA)", {
   original_locale <- Sys.getlocale("LC_COLLATE")
   Sys.setlocale("LC_COLLATE", "en_US.UTF-8")
 
-  # English language ordering
+  # English language names
   langENG <- robincar_glm(
     df=DATA,
     response_col="y",
@@ -37,7 +37,7 @@ test_that("GLM full function -- linear (ANOVA)", {
     car_scheme="simple",
     formula="y ~ A2 + x1")
 
-  # C language ordering
+  # C language names
   langC <- robincar_glm(
     df=DATA,
     response_col="y",
@@ -45,8 +45,31 @@ test_that("GLM full function -- linear (ANOVA)", {
     car_scheme="simple",
     formula="y ~ A3 + x1")
 
-  expect_equal(langENG$result$estimate, langC$result$estimate)
-  expect_equal(c(langENG$varcov), c(langC$varcov))
+  # Check that both of the orderings worked,
+  # regardless of the final order the output is in
+  # -----------------------------------------
+
+  # Benchmark ordering
+  namesENG <- c("TREAT0", "TREAT1", "TREAT2")
+  namesC <- c("TREAT0", "treat1", "TREAT2")
+
+  # Current ordering
+  currentENG <- langENG$result$treat
+  currentC <- langC$result$treat
+
+  # Get re-ordering indexes
+  reorderENG <- unname(sapply(currentENG, function(x) which(x == namesENG)))
+  reorderC <- unname(sapply(currentC, function(x) which(x == namesC)))
+
+  # Re-order estimate output and make sure they're the same
+  estENG <- unname(langENG$result$estimate[reorderENG])
+  estC <- unname(langC$result$estimate[reorderC])
+  expect_equal(estENG, estC)
+
+  # Re-order variance output and make sure they're the same
+  varENG <- unname(langENG$varcov[reorderENG, reorderENG])
+  varC <- unname(langC$varcov[reorderC, reorderC])
+  expect_equal(varENG, varC)
 
   # Reset the locale
   Sys.setlocale("LC_COLLATE", original_locale)
